@@ -137,10 +137,6 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   }
   
   
-  if (is.null(pooledvar))
-    pooledvar <- FALSE
-  
-  
   k.all <- length(n.e)
   ##
   if (k.all == 0)
@@ -395,6 +391,8 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   }
   res$print.byvar <- print.byvar
   
+  res$backtransf <- FALSE
+  
   res$version <- packageDescription("meta")$Version
   
   class(res) <- c("metacont", "meta")
