@@ -7,6 +7,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                    tau.common=FALSE,
                    prediction=.settings$prediction, level.predict=.settings$level.predict,
                    swap.events, logscale,
+                   backtransf=.settings$backtransf,
                    title, complab, outclab,
                    warn=FALSE){
   ##
@@ -105,7 +106,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
         x$TE[sel] <- log(x$TE[sel])
     }
     else
-      if ((type=="I" & method!="Peto") & sm %in% c("HR", "RR", "OR"))
+      if ((type=="I" & method!="Peto") & is.relative.effect(sm))
         warning("Assuming that values for 'TE' are on log scale. Please use argument 'logscale=FALSE' if values are on natural scale.")
   }
   
@@ -133,6 +134,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     byvar=x$grplab[sel],
                     bylab="grp",
                     print.byvar=FALSE,
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -168,6 +170,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     byvar=x$grplab[sel],
                     bylab="grp",
                     print.byvar=FALSE,
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -186,6 +189,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     print.byvar=FALSE,
                     n.e=x$n.e[sel],
                     n.c=x$n.c[sel],
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -202,6 +206,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     byvar=x$grplab[sel],
                     bylab="grp",
                     print.byvar=FALSE,
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -227,6 +232,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     tau.common=tau.common,
                     level=level, level.comb=level.comb,
                     prediction=prediction, level.predict=level.predict,
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -256,6 +262,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     tau.common=tau.common,
                     level=level, level.comb=level.comb,
                     prediction=prediction, level.predict=level.predict,
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -271,6 +278,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     prediction=prediction, level.predict=level.predict,
                     n.e=x$n.e[sel],
                     n.c=x$n.c[sel],
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
@@ -284,6 +292,7 @@ metacr <- function(x, comp.no=1, outcome.no=1,
                     tau.common=tau.common,
                     level=level, level.comb=level.comb,
                     prediction=prediction, level.predict=level.predict,
+                    backtransf=backtransf,
                     title=title,
                     complab=complab, outclab=outclab,
                     label.e=label.e, label.c=label.c,
