@@ -11,6 +11,7 @@ metagen <- function(TE, seTE,
                     ##
                     n.e=NULL, n.c=NULL,
                     ##
+                    backtransf=.settings$backtransf,
                     title=.settings$title, complab=.settings$complab, outclab="",
                     label.e=.settings$label.e, label.c=.settings$label.c,
                     label.left=.settings$label.left, label.right=.settings$label.right,
@@ -517,6 +518,8 @@ metagen <- function(TE, seTE,
   }
   res$print.byvar <- print.byvar
   
+  res$backtransf <- backtransf
+  
   res$version <- packageDescription("meta")$Version
   
   class(res) <- c("metagen", "meta")
